pub enum LoginOutcome<AccountType> {
Successful(AccountType, Cookie<'static>),
InvalidEmailOrPassword,
}Expand description
The non-error outcomes of logging in. Error outcomes are used when a genuine error takes place — e.g. the database is not reachable (represented by the functions on your DataProvider implementation returning an error).
Variants
Successful(AccountType, Cookie<'static>)
The credentials were correct, so the account and a cookie that should be set in the response to the login route are provided.
InvalidEmailOrPassword